==> haskell-optparse-simple-0.1.1.3-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optparse-simple
version:              0.1.1.3
visibility:           public
id:                   optparse-simple-0.1.1.3-Ea014HVmCogI94rtHQ4tDP
key:                  optparse-simple-0.1.1.3-Ea014HVmCogI94rtHQ4tDP
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  6123585e17b8d5310e57227350c9d7ad
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-8.10.4/site-local/optparse-simple-0.1.1.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/optparse-simple-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/optparse-simple-0.1.1.3
hs-libraries:         HSoptparse-simple-0.1.1.3-Ea014HVmCogI94rtHQ4tDP
depends:
    base-4.14.1.0 githash-0.1.5.0-H3p21T6W3EjEutKnDZ3BXl
    optparse-applicative-0.16.1.0-LAb2npSQp2PJwU2s0evoAG
    template-haskell-2.16.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.1.3-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optparse-simple
version:              0.1.1.3
visibility:           public
id:                   optparse-simple-0.1.1.3-BNGss8jK98h7FJFMg2XIA8
key:                  optparse-simple-0.1.1.3-BNGss8jK98h7FJFMg2XIA8
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  f3a919eedfac49cbb9fc9e42d82c0aae
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-8.10.4/site-local/optparse-simple-0.1.1.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/optparse-simple-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/optparse-simple-0.1.1.3
hs-libraries:         HSoptparse-simple-0.1.1.3-BNGss8jK98h7FJFMg2XIA8
depends:
    base-4.14.1.0 githash-0.1.5.0-I3MBfELfB6vHMRWMeHdhOc
    optparse-applicative-0.16.1.0-6BS7yrijROrLnaIn4WCKlt
    template-haskell-2.16.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
